@@ -204,17 +204,17 @@ gdl_dock_tablabel_set_property (GObject      *object,
 
                 g_object_get (tablabel->item,
                               "locked", &locked,
-                              "long_name", &long_name,
-                              "grip_size", &tablabel->drag_handle_size,
+                              "long-name", &long_name,
+                              "grip-size", &tablabel->drag_handle_size,
                               NULL);
 
                 if (locked)
                     tablabel->drag_handle_size = 0;
                 
                 bin = GTK_BIN (tablabel);
-                if (bin->child && g_object_class_find_property (
-                    G_OBJECT_GET_CLASS (bin->child), "label"))
-                    g_object_set (bin->child, "label", long_name, NULL);
+                if (gtk_bin_get_child (bin) && g_object_class_find_property (
+                    G_OBJECT_GET_CLASS (gtk_bin_get_child (bin)), "label"))
+                    g_object_set (gtk_bin_get_child (bin), "label", long_name, NULL);
                 g_free (long_name);
             };
             break;
@@ -257,17 +257,17 @@ gdl_dock_tablabel_item_notify (GObject    *master,
     
     g_object_get (master,
                   "locked", &locked,
-                  "grip_size", &tablabel->drag_handle_size,
-                  "long_name", &label,
+                  "grip-size", &tablabel->drag_handle_size,
+                  "long-name", &label,
                   NULL);
 
     if (locked)
         tablabel->drag_handle_size = 0;
 
     bin = GTK_BIN (tablabel);
-    if (bin->child && g_object_class_find_property (
-        G_OBJECT_GET_CLASS (bin->child), "label"))
-        g_object_set (bin->child, "label", label, NULL);
+    if (gtk_bin_get_child (bin) && g_object_class_find_property (
+        G_OBJECT_GET_CLASS (gtk_bin_get_child (bin)), "label"))
+        g_object_set (gtk_bin_get_child (bin), "label", label, NULL);
     g_free (label);
 
     gtk_widget_queue_resize (GTK_WIDGET (tablabel));
@@ -280,6 +280,7 @@ gdl_dock_tablabel_size_request (GtkWidget      *widget,
     GtkBin          *bin;
     GtkRequisition   child_req;
     GdlDockTablabel *tablabel;
+    guint            border_width;
 
     g_return_if_fail (widget != NULL);
     g_return_if_fail (GDL_IS_DOCK_TABLABEL (widget));
@@ -291,16 +292,18 @@ gdl_dock_tablabel_size_request (GtkWidget      *widget,
     requisition->width = tablabel->drag_handle_size;
     requisition->height = 0;
 
-    if (bin->child)
-        gtk_widget_size_request (bin->child, &child_req);
+    if (gtk_bin_get_child (bin))
+        gtk_widget_size_request (gtk_bin_get_child (bin), &child_req);
     else
         child_req.width = child_req.height = 0;
         
     requisition->width += child_req.width;
     requisition->height += child_req.height;
 
-    requisition->width += GTK_CONTAINER (widget)->border_width * 2;
-    requisition->height += GTK_CONTAINER (widget)->border_width * 2;
+    border_width = gtk_container_get_border_width (GTK_CONTAINER (widget));
+
+    requisition->width += border_width * 2;
+    requisition->height += border_width * 2;
 
     widget->requisition = *requisition;
 }
@@ -310,6 +313,7 @@ gdl_dock_tablabel_size_allocate (GtkWidget     *widget,
                                  GtkAllocation *allocation)
 {
     GtkBin          *bin;
+    GtkAllocation    widget_allocation;
     GdlDockTablabel *tablabel;
     gint             border_width;
 
@@ -320,22 +324,23 @@ gdl_dock_tablabel_size_allocate (GtkWidget     *widget,
     bin = GTK_BIN (widget);
     tablabel = GDL_DOCK_TABLABEL (widget);
 
-    border_width = GTK_CONTAINER (widget)->border_width;
+    border_width = gtk_container_get_border_width (GTK_CONTAINER (widget));
   
-    widget->allocation = *allocation;
+    gtk_widget_set_allocation (widget, allocation);
 
-    if (GTK_WIDGET_REALIZED (widget))
+    if (gtk_widget_get_realized (widget))
         gdk_window_move_resize (tablabel->event_window, 
                                 allocation->x, 
                                 allocation->y,
                                 allocation->width, 
                                 allocation->height);
 
-    if (bin->child && GTK_WIDGET_VISIBLE (bin->child)) {
+    if (gtk_bin_get_child (bin) && gtk_widget_get_visible (gtk_bin_get_child (bin))) {
         GtkAllocation  child_allocation;
 
-        child_allocation.x = widget->allocation.x + border_width;
-        child_allocation.y = widget->allocation.y + border_width;
+        gtk_widget_get_allocation (widget, &widget_allocation);
+        child_allocation.x = widget_allocation.x + border_width;
+        child_allocation.y = widget_allocation.y + border_width;
 
         allocation->width = MAX (1, (int) allocation->width - 
                                  (int) tablabel->drag_handle_size);
@@ -346,7 +351,7 @@ gdl_dock_tablabel_size_allocate (GtkWidget     *widget,
         child_allocation.height = 
             MAX (1, (int) allocation->height - 2 * border_width);
 
-        gtk_widget_size_allocate (bin->child, &child_allocation);
+        gtk_widget_size_allocate (gtk_bin_get_child (bin), &child_allocation);
     }
 }
 
@@ -356,23 +361,25 @@ gdl_dock_tablabel_paint (GtkWidget      *widget,
 {
     GdkRectangle     dest, rect;
     GtkBin          *bin;
+    GtkAllocation    widget_allocation;
     GdlDockTablabel *tablabel;
     gint             border_width;
 
     bin = GTK_BIN (widget);
     tablabel = GDL_DOCK_TABLABEL (widget);
-    border_width = GTK_CONTAINER (widget)->border_width;
+    border_width = gtk_container_get_border_width (GTK_CONTAINER (widget));
 
-    rect.x = widget->allocation.x + border_width;
-    rect.y = widget->allocation.y + border_width;
+    gtk_widget_get_allocation (widget, &widget_allocation);
+    rect.x = widget_allocation.x + border_width;
+    rect.y = widget_allocation.y + border_width;
     rect.width = tablabel->drag_handle_size * HANDLE_RATIO;
-    rect.height = widget->allocation.height - 2*border_width;
+    rect.height = widget_allocation.height - 2*border_width;
 
     if (gdk_rectangle_intersect (&event->area, &rect, &dest)) {
-        gtk_paint_handle (widget->style, widget->window, 
+        gtk_paint_handle (gtk_widget_get_style (widget), gtk_widget_get_window (widget), 
                           tablabel->active ? GTK_STATE_NORMAL : GTK_STATE_ACTIVE, 
                           GTK_SHADOW_NONE,
-                          &dest, widget, "dock_tablabel",
+                          &dest, widget, "dock-tablabel",
                           rect.x, rect.y, rect.width, rect.height,
                           GTK_ORIENTATION_VERTICAL);
     };
@@ -386,8 +393,8 @@ gdl_dock_tablabel_expose (GtkWidget      *widget,
     g_return_val_if_fail (GDL_IS_DOCK_TABLABEL (widget), FALSE);
     g_return_val_if_fail (event != NULL, FALSE);
 
-    if (GTK_WIDGET_VISIBLE (widget) && GTK_WIDGET_MAPPED (widget)) {
-        GDL_CALL_PARENT (GTK_WIDGET_CLASS, expose_event, (widget, event));
+    if (gtk_widget_get_visible (widget) && gtk_widget_get_mapped (widget)) {
+        GDL_CALL_PARENT_GBOOLEAN(GTK_WIDGET_CLASS, expose_event, (widget,event));
         gdl_dock_tablabel_paint (widget, event);
     };
   
@@ -399,6 +406,7 @@ gdl_dock_tablabel_button_event (GtkWidget      *widget,
                                 GdkEventButton *event)
 {
     GdlDockTablabel *tablabel;
+    GtkAllocation    widget_allocation;
     gboolean         event_handled;
   
     g_return_val_if_fail (widget != NULL, FALSE);
@@ -421,7 +429,7 @@ gdl_dock_tablabel_button_event (GtkWidget      *widget,
                 GtkBin  *bin;
 
                 bin = GTK_BIN (widget);
-                border_width = GTK_CONTAINER (widget)->border_width;
+                border_width = gtk_container_get_border_width (GTK_CONTAINER (widget));
 
                 rel_x = event->x - border_width;
                 rel_y = event->y - border_width;
@@ -459,8 +467,9 @@ gdl_dock_tablabel_button_event (GtkWidget      *widget,
 
         e = *event;
         e.window = gtk_widget_get_parent_window (widget);
-        e.x += widget->allocation.x;
-        e.y += widget->allocation.y;
+        gtk_widget_get_allocation (widget, &widget_allocation);
+        e.x += widget_allocation.x;
+        e.y += widget_allocation.y;
         
         gdk_event_put ((GdkEvent *) &e);
     };
@@ -473,6 +482,7 @@ gdl_dock_tablabel_motion_event (GtkWidget      *widget,
                                 GdkEventMotion *event)
 {
     GdlDockTablabel *tablabel;
+    GtkAllocation    widget_allocation;
     gboolean         event_handled;
   
     g_return_val_if_fail (widget != NULL, FALSE);
@@ -507,8 +517,9 @@ gdl_dock_tablabel_motion_event (GtkWidget      *widget,
 
         e = *event;
         e.window = gtk_widget_get_parent_window (widget);
-        e.x += widget->allocation.x;
-        e.y += widget->allocation.y;
+        gtk_widget_get_allocation (widget, &widget_allocation);
+        e.x += widget_allocation.x;
+        e.y += widget_allocation.y;
         
         gdk_event_put ((GdkEvent *) &e);
     };
@@ -521,15 +532,17 @@ gdl_dock_tablabel_realize (GtkWidget *widget)
 {
     GdlDockTablabel *tablabel;
     GdkWindowAttr attributes;
+    GtkAllocation widget_allocation;
     int attributes_mask;
     
     tablabel = GDL_DOCK_TABLABEL (widget);
     
     attributes.window_type = GDK_WINDOW_CHILD;
-    attributes.x = widget->allocation.x;
-    attributes.y = widget->allocation.y;
-    attributes.width = widget->allocation.width;
-    attributes.height = widget->allocation.height;
+    gtk_widget_get_allocation (widget, &widget_allocation);
+    attributes.x = widget_allocation.x;
+    attributes.y = widget_allocation.y;
+    attributes.width = widget_allocation.width;
+    attributes.height = widget_allocation.height;
     attributes.wclass = GDK_INPUT_ONLY;
     attributes.event_mask = gtk_widget_get_events (widget);
     attributes.event_mask |= (GDK_EXPOSURE_MASK | 
@@ -540,8 +553,8 @@ gdl_dock_tablabel_realize (GtkWidget *widget)
                               GDK_LEAVE_NOTIFY_MASK);
     attributes_mask = GDK_WA_X | GDK_WA_Y;
     
-    widget->window = gtk_widget_get_parent_window (widget);
-    g_object_ref (widget->window);
+    gtk_widget_set_window (widget, gtk_widget_get_parent_window (widget));
+    g_object_ref (gtk_widget_get_window (widget));
     
     tablabel->event_window = 
         gdk_window_new (gtk_widget_get_parent_window (widget),
@@ -550,7 +563,7 @@ gdl_dock_tablabel_realize (GtkWidget *widget)
     
     widget->style = gtk_style_attach (widget->style, widget->window);
     
-    GTK_WIDGET_SET_FLAGS (widget, GTK_REALIZED);
+    gtk_widget_set_realized (widget, TRUE);
 }
 
 static void   
